from cpl_core.application import ApplicationABC
from cpl_core.configuration import ConfigurationABC
from cpl_core.console import Console
from cpl_core.dependency_injection import ServiceProviderABC

from py_to_uxf_core.abc.python_parser_abc import PythonParserABC
from py_to_uxf_core.model.python_class import PythonClass


class Application(ApplicationABC):

    def __init__(self, config: ConfigurationABC, services: ServiceProviderABC):
        ApplicationABC.__init__(self, config, services)

        self._path = config.get_configuration('path')
        self._parser = services.get_service(PythonParserABC)

    def configure(self):
        pass

    def main(self):
        Console.banner('Py to UXF')
        if self._path is None:
            Console.write_line('Expected path')
            return

        Console.write_line(f'Found path:', self._path)
        classes: list[PythonClass] = self._parser.parse()

        for cls in classes:
            Console.write_line(f'Class {cls.name}')
            if len(cls.attributes) > 0:
                Console.write_line('\tAttributes:')
            for atr in cls.attributes:
                Console.write_line(f'\t{atr.access_modifier.value}{atr.name}: {atr.type}')

            if len(cls.functions) > 0:
                Console.write_line('\tFunctions:')
            for func in cls.functions:
                args = ''
                Console.write_line(f'\t{func.access_modifier.value}{func.name}({args}): {func.return_type}')
            Console.write_line()
